@@ -3,7 +3,7 @@
 Auth: coco369
 Email: 779598160@qq.com
 
-CreateTime: 2020/07/27
+CreateTime: 2021/07/27
 
 Desc: 创建爬虫项目
 """
@@ -23,7 +23,7 @@ class CreateFastSpider(object):
 		:return: 返回爬虫类型对应的模板内容
 		"""
 		if spider_type == "air":
-			tmp_name = "air_spider.tmpl"
+			tmp_name = "light_spider.tmpl"
 		elif spider_type == "nomal":
 			tmp_name = "nomal_spider.tmpl"
 		elif spider_type == "cycle":
