@@ -3,7 +3,7 @@
 Auth: coco369
 Email: 779598160@qq.com
 
-CreateTime: 2020/07/27
+CreateTime: 2021/07/27
 
 Desc: 解析启动命令行参数, 并创建对应的爬虫
 """
@@ -20,7 +20,7 @@ def create():
 		nargs="+",
 		help="创建爬虫\n"
 		     "如 fastspider startspider -s <spider_name> <spider_type> "
-		     "spider_type=air       表示创建轻量爬虫AirSpider; "
+		     "spider_type=light     表示创建轻量爬虫LightSpider; "
 		     "spider_type=nomal     分布式海量数据抓取爬虫NomalSpider; "
 		     "spider_type=cycle     分布式周期性抓取爬虫CycleSpiser; ",
 		metavar=""
@@ -31,10 +31,10 @@ def create():
 	if args.spider:
 		spider_name, *spider_type = args.spider
 		if not len(spider_type):
-			spider_type = "air"
+			spider_type = "light"
 		elif len(spider_type) == 1:
 			spider_type = spider_type[0]
 		else:
-			raise Exception('spider_type error, must choice "air" "nomal" "cycle" ')
+			raise Exception('spider_type error, must choice "light" "nomal" "cycle" ')
 
 		CreateFastSpider().create(spider_name, spider_type)
